﻿using System;
using System.IO;
using System.Web.Mvc;
using Kreta.BusinessLogic.Helpers;
using Kreta.Resources;
using Kreta.Web.Areas.Hianyzas.Models;
using Kreta.Web.Areas.OsztalyCsoport.Models;
using Kreta.Web.Helpers;

namespace Kreta.Web.Controllers.Logic
{
    /// <summary>
    /// Exportokhoz használható közös, gyűjtő logic osztály.
    /// </summary>
    public static class CommonExportLogic
    {
        public static ActionResult ExportInformaciokIgazolas(InformaciokIgazolasSearchModel model)
        {
            var stream = new IgazolasHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).GetInformaciokIgazolasExcelExport(model.ConvertToCo());
            return new FileStreamResult(stream, Core.Constants.ContentTypes.Xlsx) { FileDownloadName = $"{HianyzasResource.IgazolasokListajaExportFileName}_{DateTime.Now:yyyy_MM_dd}.{Constants.ImportExport.FileFormatXlsx}" };
        }

        public static ActionResult ExportBesorolasokOsztalyok(BaseBesorolasSearchModel model, bool isKiirt)
        {
            var helper = new TanuloHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType());
            var stream = helper.GetBesorolasOsztalyokExport(model.ConvertToCo(), isKiirt);
            string fileName;
            switch (model.OktNevFelKategoriaId)
            {
                case Enums.OktNevelesiKategoriaEnum.AlapfokuMuveszetoktatas:
                    fileName = isKiirt ? BesorolasResource.AMIOsztalybolKiirtakExportFileName : BesorolasResource.AMIOsztalybaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.EGYMI:
                    fileName = isKiirt ? BesorolasResource.EGYMIOsztalybolKiirtakExportFileName : BesorolasResource.EGYMIOsztalybaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.Felnottkepzes:
                    fileName = isKiirt ? BesorolasResource.FelnottkepzesOsztalybolKiirtakExportFileName : BesorolasResource.FelnottkepzesOsztalybaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.Kollegium:
                    fileName = isKiirt ? BesorolasResource.KollegiumOsztalybolKiirtakExportFileName : BesorolasResource.KollegiumOsztalybaBesoroltakExportFileName;
                    break;
                default:
                    fileName = isKiirt ? BesorolasResource.OsztalybolKiirtakExportFileName : BesorolasResource.OsztalybaBesoroltakExportFileName;
                    break;
            }

            return new FileStreamResult(stream, Core.Constants.ContentTypes.Xlsx) { FileDownloadName = fileName };
        }

        public static ActionResult ExportBesorolasokCsoportok(BaseBesorolasSearchModel model, bool isKiirt)
        {
            var helper = new TanuloHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType());
            var stream = helper.GetBesorolasCsoportokExport(model.ConvertToCo(), isKiirt);
            string fileName;
            switch (model.OktNevFelKategoriaId)
            {
                case Enums.OktNevelesiKategoriaEnum.AlapfokuMuveszetoktatas:
                    fileName = isKiirt ? BesorolasResource.AMICsoportbolKiirtakExportFileName : BesorolasResource.AMICsoportbaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.EGYMI:
                    fileName = isKiirt ? BesorolasResource.EGYMICsoportbolKiirtakExportFileName : BesorolasResource.EGYMICsoportbaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.Felnottkepzes:
                    fileName = isKiirt ? BesorolasResource.FelnottkepzesCsoportbolKiirtakExportFileName : BesorolasResource.FelnottkepzesCsoportbaBesoroltakExportFileName;
                    break;
                case Enums.OktNevelesiKategoriaEnum.Kollegium:
                    fileName = isKiirt ? BesorolasResource.KollegiumCsoportbolKiirtakExportFileName : BesorolasResource.KollegiumCsoportbaBesoroltakExportFileName;
                    break;
                default:
                    fileName = isKiirt ? BesorolasResource.CsoportbolKiirtakExportFileName : BesorolasResource.CsoportbaBesoroltakExportFileName;
                    break;
            }

            return new FileStreamResult(stream, Core.Constants.ContentTypes.Xlsx) { FileDownloadName = fileName };
        }
    }
}
